@@ -81,20 +81,59 @@ compute_adjustment<-function(r.x1.y,r.x2.y,r.x1x2.y,r.x1.x2,
     c1<-stats::cor(a2)
 
     sim_error<-max(abs((target_matrix - c1[lower.tri(c1)]) [-c(3,5) ]))
-    m2b<-c1[lower.tri(c1)]
+
+
     m1b<-target_matrix
-    b<-matrix(t(c(m1b,m2b)),ncol = 2)
+    m2b<-c1[lower.tri(c1)]
+    m3b = c((r.x1.x2+adjustments[1]),
+            (r.x1.y+adjustments[2]),
+            0,
+            (r.x2.y+adjustments[4]),
+            0,
+            (r.x1x2.y+adjustments[6]))
+
+    b<-matrix(t(c(m1b,m2b,m3b)),ncol = 3) # target, observed, settings
 
 
     adjust<-apply(b,MARGIN = 1,FUN = function(x){
 
-      d<-base::data.frame(y =c(0,x[1]),x= c(0,x[2]))
+      d<-base::data.frame(y =c(0,x[3]),x= c(0,x[2]))
       f1<-stats::lm( y~x,data = d )
       p0<-polynom::polynomial(stats::coefficients(f1))
       return(stats::predict(p0,x[1]))
     })
 
-    adjustments<-adjustments + (adjust - b[,1])
+
+
+    cor.mat = base::matrix(data = 0,nrow = 4,ncol = 4) %>% base::as.data.frame()
+    base::diag(cor.mat) = 1
+    ind <- base::which( base::lower.tri(cor.mat,diag=F) , arr.ind = TRUE )
+    cor.mat[ind]=adjust
+    ind2=ind
+    ind2[,1]=ind[,2]
+    ind2[,2]=ind[,1]
+    cor.mat[ind2]=adjust
+
+    while(min(eigen(cor.mat,only.values = T)$values)<0){
+      cor.pd = Matrix::nearPD(x = as.matrix(cor.mat),keepDiag = T,corr = T,do2eigen = T)$mat
+      cor.pd = cor.pd[base::lower.tri(cor.pd,diag=F)]
+
+      max.diff = which(abs(cor.pd - adjust)[-c(3,5)] == max(abs(cor.pd - adjust)[-c(3,5)]))
+
+      adjust[-c(3,5)] [max.diff] = cor.pd[-c(3,5)] [max.diff]
+
+      cor.mat = base::matrix(data = 0,nrow = 4,ncol = 4) %>% base::as.data.frame()
+      base::diag(cor.mat) = 1
+      ind <- base::which( base::lower.tri(cor.mat,diag=F) , arr.ind = TRUE )
+      cor.mat[ind]=adjust
+      ind2=ind
+      ind2[,1]=ind[,2]
+      ind2[,2]=ind[,1]
+      cor.mat[ind2]=adjust
+      }
+
+      adjustments<-(adjust - b[,1])
+
 
     if(max(adjustments+target_matrix)>1){
 
@@ -105,6 +144,11 @@ compute_adjustment<-function(r.x1.y,r.x2.y,r.x1x2.y,r.x1.x2,
 
     }
 
+  if(sim_error>tol ){
+    stop(paste("Data cannot be transformed to desired distribution. Error (",round(sim_error,4),") is greater than tol (",tol,") Try reducing correlations, increasing tolerance, or increasing the number of iterations.",sep=""))
+
+  }
+
   return(adjustments)
 }
 
